Welcome to django-authority’s documentation! — django-authority v0.2 documentation

### Navigation

- index
- next |
- django-authority v0.2 documentation »

# Welcome to django-authority’s documentation!

django-authority is a powerful layer between Django’s basic permission system (provided through `django.contrib.auth`) and your application:

This application provides three abilities:

1. It gives you the ability to add permissions like Django’s generic permissions to any kind of model without having to add them to the model’s Meta class.
2. It provides a very simple way to create per-object-permissions. You might be more familiar with the term row level permissions.
3. It wraps Django’s generic permissions so you can use the same syntax as for the options above. But note that django-authority does not add any voodoo-code to Django’s `contrib.auth` system, it keeps your existing permission system intact!

Warning

We have just started with the documentation and it’s far from being perfect. If you find glitches, errors or just have feedback, please contact the team: Support.

## Documentation

Note

The create-permission topics are based on each other. If you are new to django-authority we encourage to read from top to bottom.

Installation topics:

- Installation
- Configuration

Create and check permissions:

- Create a basic permission
- Create a per-object permission
- Create a custom permission

Permission checks in detail

- Check permissions in python code
- Check permissions using the decorator
  - The decorator syntax
  - Contributed decorators
- Check permissions in templates
  - ifhasperm
  - get_permissions
  - get_permission

Permission assigning and handling

- Handling permissions in python code
- Handling permissions using Django’s admin interface
- Handling permissions using templates

## Other pages

- Search Page
- Index

- Hints, tips and tricks
- Support
- Documentation Guildlines

### Navigation

- index
- next |
- django-authority v0.2 documentation »